@@ -106,6 +106,7 @@ module gt4_historyauto
    use dc_types, only: STRING, TOKEN
    use dc_trace, only: BeginSub, EndSub, DbgMessage
    !!use gtdata_types, only: GT_VARIABLE
+   use dc_present, only: present_and_true
    use gt4_history, only: GT_HISTORY, HistoryCreate, HistoryPut, &
 	& HistoryClose, HistoryAddVariable, HistorySetTime, &
 	& HistoryAddAttr, HistoryInquire, Inquire, GT_HISTORY_VARINFO
@@ -161,6 +162,8 @@ module gt4_historyauto
       integer              :: slfst(3)
       integer              :: sllst(3)
       integer              :: slstp(3)
+      logical              :: domain_div
+      integer              :: subdomfst(3)
       ! needed for HistoryCreate:
       character(len=STRING)  :: file
       character(len=TOKEN)   :: proc
@@ -180,6 +183,7 @@ module gt4_historyauto
       real                   :: dt        ! model time step (to quantize upon)
       character(len=STRING)  :: conventions
       character(len=TOKEN)   :: gt_version
+      logical :: out_of_domain
       ! spastal coordinate variables:
       type(GT4_REAL1D)           :: spcoordvars(3) 
       type(GT4_NAMED_REALARY),pointer  :: ancilcrdvars(:) =>null()
@@ -200,9 +204,9 @@ module gt4_historyauto
    type(HIST_LINK),save,pointer:: HISTGRIDPOOL => NULL()  ! Fortran95 feature
 
    integer,parameter           :: max_char_len = 200
-   character(len=max_char_len) :: com_proc=''
-   character(len=max_char_len) :: com_title='', com_source='', com_institution=''
-   character(len=max_char_len) :: com_conventions='', com_gt_version='4.2'
+   character(len=max_char_len),save :: com_proc=''
+   character(len=max_char_len),save :: com_title='', com_source='', com_institution=''
+   character(len=max_char_len),save :: com_conventions='', com_gt_version='4.2'
 
 contains
 
@@ -436,7 +440,7 @@ contains
       do while( histpl_find(HISTPOOL, name, ith, hst) )
 	 put_now = whether_to_put_now( time, hst%time_last, &
 	                   & hst%time_to_start, hst%put_interval, hst%dt )
-	 if ( put_now ) then
+	 if ( put_now .and. .not.hst%out_of_domain ) then
 	    if ( associated(hst%h%hs) ) then
 	       call HistoryInquire(hst%h%hs, newest=newest)
 	       if ( hst%newfile_interval > 0 .and. &
@@ -640,7 +644,8 @@ contains
 
    subroutine HistoryAutoSetGrid( grid_label, aryshape, &
         & dims, axlongnames, axunits, axxtypes, &
-	& coord1, coord2, coord3, ancilcrdvars )
+	& coord1, coord2, coord3, ancilcrdvars, &
+        & subdomfst )
       use dc_error, only: USR_EINT, StoreError
       implicit none
       character(len=*), intent(in)     :: grid_label
@@ -653,6 +658,8 @@ contains
       real, intent(in),optional        :: coord2(:) ! must present if sprank>=2
       real, intent(in),optional        :: coord3(:) ! must present if sprank>=3
       type(GT4_NAMED_REALARY),intent(in),optional  :: ancilcrdvars(:)
+      integer, intent(in),optional :: subdomfst(:) ! For domain-dividing comp.
+                      ! first indx relative in the whole dom. (size == sprank)
       !
       type(HIST_EACHVAR)            :: hist
       integer                       :: sprank
@@ -669,6 +676,12 @@ contains
       hist%axlongnames(1:sprank+1) = axlongnames(1:sprank+1)
       hist%axunits(1:sprank+1) = axunits(1:sprank+1)
       hist%axxtypes(1:sprank+1) = axxtypes(1:sprank+1)
+      if (present(subdomfst)) then
+         hist%domain_div = .true.
+         hist%subdomfst(1:sprank) = subdomfst(1:sprank)
+      else
+         hist%domain_div = .false.
+      endif
 
       if (sprank >= 1) hist%spcoordvars(1) = init_gt4_real1d( coord1 )
       if (sprank >= 2) hist%spcoordvars(2) = init_gt4_real1d( coord2 )
@@ -731,7 +744,8 @@ contains
 	& hist%dims(1:hist%sprank+1), hist%axlongnames(1:hist%sprank+1), &
 	& hist%axunits(1:hist%sprank+1), hist%axxtypes(1:hist%sprank+1), &
 	& hist%spcoordvars, hist%ancilcrdvars, &
-	& title, source, institution, conventions, gt_version, proc )
+	& title, source, institution, conventions, gt_version, proc, &
+        & hist%domain_div, hist%subdomfst )
 
       call EndSub(subname)
    end subroutine HistoryAutoCreate2
@@ -743,7 +757,8 @@ contains
 	& attrs, &
         & aryshape, dims, axlongnames, axunits, axxtypes, &
 	& spcoordvars, ancilcrdvars, &
-	& title, source, institution, conventions, gt_version, proc )
+	& title, source, institution, conventions, gt_version, proc, &
+        & domain_div, subdomfst )
       use dc_error, only: USR_EINT, StoreError
       implicit none
       character(len=*), intent(in)     :: name
@@ -766,9 +781,12 @@ contains
       character(len=*), intent(in),optional  :: proc
       character(len=*), intent(in),optional  :: title, source, institution
       character(len=*), intent(in),optional  :: conventions, gt_version
+      logical, intent(in),optional :: domain_div
+      integer, intent(in),optional :: subdomfst(*) ! For domain-dividing comp.
+                      ! first indx relative in the whole dom. (size == sprank)
       !
       type(HIST_EACHVAR)            :: hist
-      integer                       :: sprank,i
+      integer                       :: sprank,i,slf
       character(len = *),parameter  :: subname = "HistoryAutoCreate1"
 
       call BeginSub(subname)
@@ -786,38 +804,81 @@ contains
       sprank = min( size(aryshape), 3 )
       hist%sprank = sprank
 
+         
+      if ( present_and_true(domain_div) ) then
+         hist%domain_div = .true.
+         if (.not. present(subdomfst)) call StoreError(USR_EINT, subname, &
+              & cause_c='When domain_div is present and true, subdomfst '// &
+              & 'must also be present.')
+      else
+         hist%domain_div = .false.
+      end if
+
+      if (hist%domain_div .and. &
+           & (minval(slfst(1:sprank)).le.0 .or. &
+           &  minval(sllst(1:sprank)).lt.0) ) then
+	 call StoreError(USR_EINT, subname, &
+              & cause_c='When the domain is divided, output-domain '//&
+              & 'limiting from the end by using negative indices is not '//&
+              & 'available, since the whole domain size is not known. '//&
+              & 'Use a postive number (or zero for sllst to express the'//&
+              & ' last grid point).')
+      endif
+
       hist%size = 1
+      hist%out_of_domain = .false.   ! Init. May be true in domain division.
+
       do i=1,sprank
 	 hist%aryshape(i) = aryshape(i)
-	 if(slfst(i) > 0) then
-	    hist%slfst(i) = slfst(i)
-	 else
-	    hist%slfst(i) = slfst(i) + aryshape(i)
-	 endif
-	 if(sllst(i) > 0) then
-	    hist%sllst(i) = sllst(i)
-	 else
-	    hist%sllst(i) = sllst(i) + aryshape(i)
-	 endif
-	 if(slstp(i) > 0) then
-	    hist%slstp(i) = slstp(i)
-	 else
-	    hist%slstp(i) = 1
-	 endif
-	 hist%dimsizes(i) = (hist%sllst(i)-hist%slfst(i))/hist%slstp(i) + 1
-	 if (hist%slfst(i)<=0 .or. hist%slfst(i)>aryshape(i)) &
-	      & call StoreError(USR_EINT, subname, &
-	      &   cause_c='str not within the index range for dim:', cause_i=i)
-	 if (hist%sllst(i)<=0 .or. hist%sllst(i)>aryshape(i)) &
-	      & call StoreError(USR_EINT, subname, &
-	      &   cause_c='end not within the index range for dim:', cause_i=i)
-	 if (hist%slstp(i)<=0) &
-	      & call StoreError(USR_EINT, subname, &
-	      &   cause_c='step not positive for dim:', cause_i=i)
-	 if (hist%dimsizes(i)<=0) &
-	      & call StoreError(USR_EINT, subname, &
-	      &   cause_c='negative dimsize for dim:', cause_i=i)
-	 hist%size = hist%size * hist%dimsizes(i)
+         if(slstp(i) > 0) then
+            hist%slstp(i) = slstp(i)
+         else
+            hist%slstp(i) = 1
+         endif
+         if (.not.hist%domain_div) then
+            if(slfst(i) > 0) then
+               hist%slfst(i) = slfst(i)
+            else
+               hist%slfst(i) = slfst(i) + aryshape(i)
+            endif
+            if(sllst(i) > 0) then
+               hist%sllst(i) = sllst(i)
+            else
+               hist%sllst(i) = sllst(i) + aryshape(i)
+            endif
+         else
+            slf = slfst(i) - subdomfst(i) + 1
+            if (slf.le.0) then
+               slf = modulo(slf-1,hist%slstp(i)) + 1
+            else if(slf.gt.aryshape(i)) then
+               hist%out_of_domain = .true.
+            endif
+            hist%slfst(i) = slf
+            if (sllst(i).eq.0) then
+               hist%sllst(i) = aryshape(i)
+            else
+               hist%sllst(i) = min( sllst(i) - subdomfst(i) + 1, aryshape(i) )
+               if (hist%sllst(i).le.0) then
+                  hist%out_of_domain = .true.
+               endif
+            endif
+         endif
+         hist%dimsizes(i) = (hist%sllst(i)-hist%slfst(i))/hist%slstp(i) + 1
+         if (.not.hist%domain_div) then
+            if (hist%slfst(i)<=0 .or. hist%slfst(i)>aryshape(i)) &
+                 & call StoreError(USR_EINT, subname, cause_c= &
+                 &   'str not within the index range for dim:',cause_i=i)
+            if (hist%sllst(i)<=0 .or. hist%sllst(i)>aryshape(i)) &
+                 & call StoreError(USR_EINT, subname, cause_c= &
+                 &   'end not within the index range for dim:',cause_i=i)
+            if (hist%slstp(i)<=0) &
+                 & call StoreError(USR_EINT, subname, &
+                 &   cause_c='step not positive for dim:', cause_i=i)
+            if (hist%dimsizes(i)<=0) &
+                 & call StoreError(USR_EINT, subname, &
+                 &   cause_c='negative dimsize for dim:', cause_i=i)
+         endif
+         hist%size = hist%size * hist%dimsizes(i)
       enddo
       hist%dimsizes(sprank+1) = 0   ! unlimited dimension
 
@@ -866,7 +927,7 @@ contains
  	 nullify(hist%ancilcrdvars)
       else if ( size(ancilcrdvars)==0 )then
  	 nullify(hist%ancilcrdvars)
-      else
+      else	
 	 allocate(hist%ancilcrdvars(size(ancilcrdvars))) ! always new alloc
 	 hist%ancilcrdvars = ancilcrdvars
       endif
