@@ -13,7 +13,7 @@ ${MAKE:-make} histtest
 NCDUMP=${NCDUMP:-ncdump}
 MKDIR=${MKDIR:-mkdir}
 
-if ! $NCDUMP > /dev/null 2>&1  ;then
+if ! $NCDUMP ncdump_check.nc > /dev/null 2>&1  ;then
     echo ""
     echo "   Error: $NCDUMP: command not found."
     echo ""
@@ -51,8 +51,8 @@ date_to_unknown='s/[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]T[0-9][0-9]:[0-9][0
 
 echo $ECHO_N "histtest [Basic Create test (Conventions auto output)] ... " $ECHO_C
 
-ncdump xhisttest1.nc    | sed $date_to_unknown > xhisttest1.cdl
-ncdump xhisttest1org.nc | sed $date_to_unknown > xhisttest1org.cdl
+$NCDUMP xhisttest1.nc    | sed $date_to_unknown > xhisttest1.cdl
+$NCDUMP xhisttest1org.nc | sed $date_to_unknown > xhisttest1org.cdl
 
 diff xhisttest1.cdl xhisttest1org.cdl > xhisttest1dif.cdl ||
 
@@ -71,8 +71,8 @@ rm -f xhisttest1.nc xhisttest1*.cdl xhisttest1dif.cdl
 
 echo $ECHO_N "histtest [Auto Set Time test (gt_version manually output)] ... " $ECHO_C
 
-ncdump xhisttest2.nc    | sed $date_to_unknown    > xhisttest2.cdl
-ncdump xhisttest2org.nc | sed $date_to_unknown    > xhisttest2org.cdl
+$NCDUMP xhisttest2.nc    | sed $date_to_unknown    > xhisttest2.cdl
+$NCDUMP xhisttest2org.nc | sed $date_to_unknown    > xhisttest2org.cdl
 diff xhisttest2.cdl xhisttest2org.cdl > xhisttest2dif.cdl ||
 
 diff xhisttest2dif.cdl - <<EOF
@@ -90,8 +90,8 @@ rm -f xhisttest2.nc xhisttest2*.cdl xhisttest2dif.cdl
 
 echo $ECHO_N "histtest [Set Time by HistoryPut test (Conventions, gt_version manually output) (origin, interval auto setting)] ... " $ECHO_C
 
-ncdump xhisttest3.nc    | sed $date_to_unknown    > xhisttest3.cdl
-ncdump xhisttest3org.nc | sed $date_to_unknown    > xhisttest3org.cdl
+$NCDUMP xhisttest3.nc    | sed $date_to_unknown    > xhisttest3.cdl
+$NCDUMP xhisttest3org.nc | sed $date_to_unknown    > xhisttest3org.cdl
 diff xhisttest3.cdl xhisttest3org.cdl > xhisttest3dif.cdl ||
 
 diff xhisttest3dif.cdl - <<EOF
@@ -110,8 +110,8 @@ rm -f xhisttest3.nc xhisttest3*.cdl xhisttest3dif.cdl
 
 echo $ECHO_N "histtest [HistorySetTime test] ... " $ECHO_C
 
-ncdump xhisttest4.nc    | sed $date_to_unknown    > xhisttest4.cdl
-ncdump xhisttest4org.nc | sed $date_to_unknown    > xhisttest4org.cdl
+$NCDUMP xhisttest4.nc    | sed $date_to_unknown    > xhisttest4.cdl
+$NCDUMP xhisttest4org.nc | sed $date_to_unknown    > xhisttest4org.cdl
 diff xhisttest4.cdl xhisttest4org.cdl > xhisttest4dif.cdl ||
 
 diff xhisttest4dif.cdl - <<EOF
@@ -131,8 +131,8 @@ rm -f xhisttest4.nc xhisttest4*.cdl xhisttest4dif.cdl
 
 echo $ECHO_N "histtest [HistoryCreate without Argument Keyword test] ... " $ECHO_C
 
-ncdump xhisttest5.nc    | sed $date_to_unknown    > xhisttest5.cdl
-ncdump xhisttest5org.nc | sed $date_to_unknown    > xhisttest5org.cdl
+$NCDUMP xhisttest5.nc    | sed $date_to_unknown    > xhisttest5.cdl
+$NCDUMP xhisttest5org.nc | sed $date_to_unknown    > xhisttest5org.cdl
 diff xhisttest5.cdl xhisttest5org.cdl > xhisttest5dif.cdl ||
 
 diff xhisttest5dif.cdl - <<EOF
@@ -152,8 +152,8 @@ rm -f xhisttest5.nc xhisttest5*.cdl xhisttest5dif.cdl
 
 echo $ECHO_N "histtest [HistoryAddAttr test] ... " $ECHO_C
 
-ncdump xhisttest6.nc    | sed $date_to_unknown    > xhisttest6.cdl
-ncdump xhisttest6org.nc | sed $date_to_unknown    > xhisttest6org.cdl
+$NCDUMP xhisttest6.nc    | sed $date_to_unknown    > xhisttest6.cdl
+$NCDUMP xhisttest6org.nc | sed $date_to_unknown    > xhisttest6org.cdl
 diff xhisttest6.cdl xhisttest6org.cdl > xhisttest6dif.cdl ||
 
 diff xhisttest6dif.cdl - <<EOF
@@ -172,8 +172,8 @@ rm -f xhisttest6.nc xhisttest6*.cdl xhisttest6dif.cdl
 
 echo $ECHO_N "histtest [HistoryCopy test 1] ... " $ECHO_C
 
-ncdump xhisttest7.nc    | sed $date_to_unknown    > xhisttest7.cdl
-ncdump xhisttest7org.nc | sed $date_to_unknown    > xhisttest7org.cdl
+$NCDUMP xhisttest7.nc    | sed $date_to_unknown    > xhisttest7.cdl
+$NCDUMP xhisttest7org.nc | sed $date_to_unknown    > xhisttest7org.cdl
 diff xhisttest7.cdl xhisttest7org.cdl > xhisttest7dif.cdl ||
 
 diff xhisttest7dif.cdl - <<EOF
@@ -193,8 +193,8 @@ rm -f xhisttest7.nc xhisttest7*.cdl xhisttest7dif.cdl
 
 echo $ECHO_N "histtest [HistoryCopy test 2] ... " $ECHO_C
 
-ncdump xhisttest8.nc    | sed $date_to_unknown    > xhisttest8.cdl
-ncdump xhisttest8org.nc | sed $date_to_unknown    > xhisttest8org.cdl
+$NCDUMP xhisttest8.nc    | sed $date_to_unknown    > xhisttest8.cdl
+$NCDUMP xhisttest8org.nc | sed $date_to_unknown    > xhisttest8org.cdl
 diff xhisttest8.cdl xhisttest8org.cdl > xhisttest8dif.cdl ||
 
 diff xhisttest8dif.cdl - <<EOF
@@ -213,8 +213,8 @@ rm -f xhisttest8.nc xhisttest8*.cdl xhisttest8dif.cdl
 
 echo $ECHO_N "histtest [\"range\" argument test in HistoryPut test] ... " $ECHO_C
 
-ncdump xhisttest9.nc    | sed $date_to_unknown    > xhisttest9.cdl
-ncdump xhisttest9org.nc | sed $date_to_unknown    > xhisttest9org.cdl
+$NCDUMP xhisttest9.nc    | sed $date_to_unknown    > xhisttest9.cdl
+$NCDUMP xhisttest9org.nc | sed $date_to_unknown    > xhisttest9org.cdl
 diff xhisttest9.cdl xhisttest9org.cdl > xhisttest9dif.cdl ||
 
 diff xhisttest9dif.cdl - <<EOF
